@@ -187,29 +187,26 @@ class LearnRegressionError:
             # Populating Metric Scores for Validation Error Model
             self.algorithm_performance_df.loc[key, 'Error Model Validation MAE'] = mean_absolute_error(self.validation['Current Model Error'], model_predictions_validation)
             self.algorithm_performance_df.loc[key, 'Error Model Validation RMSE'] = self.np.sqrt(mean_squared_error(self.validation['Current Model Error'],model_predictions_validation))
-            if (model_predictions_validation < 0).any() or (self.validation['Current Model Error'] < 0).any():
+            self.algorithm_performance_df.loc[key, 'Error Model Validation R2-Score'] = r2_score(
+                self.validation['Current Model Error'], model_predictions_validation)
+            try:
+                self.algorithm_performance_df.loc[key, 'Error Model Validation RMSLE'] = self.np.sqrt(mean_squared_log_error(self.validation['Current Model Error'],model_predictions_validation))
+            except ValueError:
                 pass
-            else:
-                try:
-                    self.algorithm_performance_df.loc[key, 'Error Model Validation RMSLE'] = self.np.sqrt(mean_squared_log_error(self.validation['Current Model Error'],model_predictions_validation))
-                except ValueError:
-                    pass
-            self.algorithm_performance_df.loc[key, 'Error Model Validation R2-Score'] = r2_score(self.validation['Current Model Error'], model_predictions_validation)
+
 
             # Populating Metric Scores for Test Error Model
             self.algorithm_performance_df.loc[key, 'Error Model Test MAE'] = mean_absolute_error(
                 self.test['Current Model Error'], model_predictions_test)
             self.algorithm_performance_df.loc[key, 'Error Model Test RMSE'] = self.np.sqrt(
                 mean_squared_error(self.test['Current Model Error'], model_predictions_test))
-            if (model_predictions_validation < 0).any() or (self.test['Current Model Error'] < 0).any():
-                pass
-            else:
-                try:
-                    self.algorithm_performance_df.loc[key, 'Error Model Test RMSLE'] = self.np.sqrt(mean_squared_log_error(self.test['Current Model Error'],model_predictions_test))
-                except ValueError:
-                    pass
             self.algorithm_performance_df.loc[key, 'Error Model Test R2-Score'] = r2_score(
                 self.test['Current Model Error'], model_predictions_test)
+            try:
+                self.algorithm_performance_df.loc[key, 'Error Model Test RMSLE'] = self.np.sqrt(mean_squared_log_error(self.test['Current Model Error'],model_predictions_test))
+            except ValueError:
+                pass
+
 
             # Populating Metric Scores for Validation Final Output
             final_output_validation = self.validation['Current Model Predictions'] + model_predictions_validation
@@ -219,15 +216,13 @@ class LearnRegressionError:
                 self.validation[self.output_label], final_output_validation)
             self.algorithm_performance_df.loc[key, 'Final Output Validation RMSE'] = self.np.sqrt(
                 mean_squared_error(self.validation[self.output_label], final_output_validation))
-            if (final_output_validation < 0).any() or (self.validation[self.output_label] < 0).any():
-                pass
-            else:
-                try:
-                    self.algorithm_performance_df.loc[key, 'Final Output Validation RMSLE'] = self.np.sqrt(mean_squared_log_error(self.validation[self.output_label],final_output_validation))
-                except ValueError:
-                    pass
             self.algorithm_performance_df.loc[key, 'Final Output Validation R2-Score'] = r2_score(
                 self.validation[self.output_label], final_output_validation)
+            try:
+                self.algorithm_performance_df.loc[key, 'Final Output Validation RMSLE'] = self.np.sqrt(mean_squared_log_error(self.validation[self.output_label],final_output_validation))
+            except ValueError:
+                pass
+
 
             # Populating Metric Scores for Test Final Output
             final_output_test = self.test['Current Model Predictions'] + model_predictions_test
@@ -236,15 +231,12 @@ class LearnRegressionError:
                 self.test[self.output_label], final_output_test)
             self.algorithm_performance_df.loc[key, 'Final Output Test RMSE'] = self.np.sqrt(
                 mean_squared_error(self.test[self.output_label], final_output_test))
-            if (final_output_test < 0).any() or (self.test[self.output_label] < 0).any():
-                pass
-            else:
-                try:
-                    self.algorithm_performance_df.loc[key, 'Final Output Test RMSLE'] = self.np.sqrt(mean_squared_log_error(self.test[self.output_label], final_output_test))
-                except ValueError:
-                    pass
             self.algorithm_performance_df.loc[key, 'Final Output Test R2-Score'] = r2_score(
                 self.test[self.output_label], final_output_test)
+            try:
+                self.algorithm_performance_df.loc[key, 'Final Output Test RMSLE'] = self.np.sqrt(mean_squared_log_error(self.test[self.output_label], final_output_test))
+            except ValueError:
+                pass
 
         # Sorting Dataframe as per selected evaluation metric
         if self.focus_metric == 'mae':
